Learn R Programming

clintools (version 0.9.10.1)

rowMedians: find median of rows similar to rowMeans (rowMedians)

Description

rowMedians() converts a dataframe to a list of row medians.

Usage

rowMedians(x, na.rm=FALSE)

Value

Returns a list of the median of each row in the inputted dataframe.

Arguments

x

a dataframe where median of row should be calculated. (data.frame)

na.rm

Should missing values be omitted fro the calculations? (boolian)

Examples

Run this code
if (FALSE) {
   rowMedians(df[,c("test1","test2","test3")])
}

Run the code above in your browser using DataLab