powered by
rowMedians() converts a dataframe to a list of row medians.
rowMedians()
rowMedians(x, na.rm=FALSE)
Returns a list of the median of each row in the inputted dataframe.
a dataframe where median of row should be calculated. (data.frame)
data.frame
Should missing values be omitted fro the calculations? (boolian)
boolian
if (FALSE) { rowMedians(df[,c("test1","test2","test3")]) }
Run the code above in your browser using DataLab